@@ -2,7 +2,7 @@ use bevy::prelude::*;
 use bevy_console::*;
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(ConsolePlugin)
         .insert_resource(ConsoleConfiguration {
